@@ -101,6 +101,7 @@ static gchar *contributors[] = {
 	"Christopher R. Gabriel",
 	"Mark Galassi",
 	"Tony Gale",
+	"Carlos Garc\xc3\xad" "a Campos",
 	"Matthew Garrett",
 	"Carlos Garnacho Parro",
 	"Jeff Garzik",
@@ -196,6 +197,7 @@ static gchar *contributors[] = {
 	"Gordon Matzigkeit",
 	"Dietmar Maurer",
 	"Justin Maurer",
+	"Shaun McCance",
 	"Gregory McLean",
 	"Mark McLoughlin",
 	"Michael Meeks",
